==> bioreadout-0.2.0.tar.gz: bioreadout-0.2.0/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
✨ Added `lookup` of efo | [13](https://github.com/laminlabs/bioreadout/pull/13) | [sunnyosun](https://github.com/sunnyosun) | 2022-10-12 | 0.2.0
🔥 Removed lookup | [12](https://github.com/laminlabs/bioreadout/pull/12) | [sunnyosun](https://github.com/sunnyosun) | 2022-10-06 |
🐛 Fixed return type | [11](https://github.com/laminlabs/bioreadout/pull/11) | [sunnyosun](https://github.com/sunnyosun) | 2022-09-22 | 0.1.2
🩹 Return str instead of list in EFO parsing | [10](https://github.com/laminlabs/bioreadout/pull/10) | [sunnyosun](https://github.com/sunnyosun) | 2022-09-22 | 0.1.1
🚚 Rename `readout_type` to `readout` | [7](https://github.com/laminlabs/bioreadout/pull/7) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-26 | 0.1.0
✨ Added EFO class | [6](https://github.com/laminlabs/bioreadout/pull/6) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-10 | 0.0.5
🚚 Rename repo to `bioreadout` | [5](https://github.com/laminlabs/bioreadout/pull/5) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-04 |
🚚 Rename vocabulary to lookup | [3](https://github.com/laminlabs/bioreadout/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-31 | 0.0.4
🚚 Rename literal to vocabulary | [2](https://github.com/laminlabs/bioreadout/pull/2) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-27 | 0.0.3
✨ Added `readout` and `readout_platform` | [1](https://github.com/laminlabs/bioreadout/pull/1) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-27 | 0.0.2

==> bioreadout-0.2.1.tar.gz: bioreadout-0.2.1/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🚀 Fixed docs | [14](https://github.com/laminlabs/bioreadout/pull/14) | [sunnyosun](https://github.com/sunnyosun) | 2022-10-12 | 0.2.1
✨ Added `lookup` of efo | [13](https://github.com/laminlabs/bioreadout/pull/13) | [sunnyosun](https://github.com/sunnyosun) | 2022-10-12 | 0.2.0
🔥 Removed lookup | [12](https://github.com/laminlabs/bioreadout/pull/12) | [sunnyosun](https://github.com/sunnyosun) | 2022-10-06 |
🐛 Fixed return type | [11](https://github.com/laminlabs/bioreadout/pull/11) | [sunnyosun](https://github.com/sunnyosun) | 2022-09-22 | 0.1.2
🩹 Return str instead of list in EFO parsing | [10](https://github.com/laminlabs/bioreadout/pull/10) | [sunnyosun](https://github.com/sunnyosun) | 2022-09-22 | 0.1.1
🚚 Rename `readout_type` to `readout` | [7](https://github.com/laminlabs/bioreadout/pull/7) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-26 | 0.1.0
✨ Added EFO class | [6](https://github.com/laminlabs/bioreadout/pull/6) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-10 | 0.0.5
🚚 Rename repo to `bioreadout` | [5](https://github.com/laminlabs/bioreadout/pull/5) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-04 |
🚚 Rename vocabulary to lookup | [3](https://github.com/laminlabs/bioreadout/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-31 | 0.0.4
🚚 Rename literal to vocabulary | [2](https://github.com/laminlabs/bioreadout/pull/2) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-27 | 0.0.3
✨ Added `readout` and `readout_platform` | [1](https://github.com/laminlabs/bioreadout/pull/1) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-27 | 0.0.2
